==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/avs/kotlin/inputs/GetHcxEnterpriseSitePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.avs.kotlin.inputs

import com.pulumi.azurenative.avs.inputs.GetHcxEnterpriseSitePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property hcxEnterpriseSiteName Name of the HCX Enterprise Site in the private cloud
 * @property privateCloudName Name of the private cloud
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 */
public data class GetHcxEnterpriseSitePlainArgs(
    public val hcxEnterpriseSiteName: String,
    public val privateCloudName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.avs.inputs.GetHcxEnterpriseSitePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.avs.inputs.GetHcxEnterpriseSitePlainArgs =
        com.pulumi.azurenative.avs.inputs.GetHcxEnterpriseSitePlainArgs.builder()
            .hcxEnterpriseSiteName(hcxEnterpriseSiteName.let({ args0 -> args0 }))
            .privateCloudName(privateCloudName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetHcxEnterpriseSitePlainArgs].
 */
@PulumiTagMarker
public class GetHcxEnterpriseSitePlainArgsBuilder internal constructor() {
    private var hcxEnterpriseSiteName: String? = null

    private var privateCloudName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value Name of the HCX Enterprise Site in the private cloud
     */
    @JvmName("fyvnpdtmajoxjglb")
    public suspend fun hcxEnterpriseSiteName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.hcxEnterpriseSiteName = mapped
    }

    /**
     * @param value Name of the private cloud
     */
    @JvmName("cwiknnfuuoqestxi")
    public suspend fun privateCloudName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.privateCloudName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("gbqyleanolfldpkg")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetHcxEnterpriseSitePlainArgs = GetHcxEnterpriseSitePlainArgs(
        hcxEnterpriseSiteName = hcxEnterpriseSiteName ?: throw
            PulumiNullFieldException("hcxEnterpriseSiteName"),
        privateCloudName = privateCloudName ?: throw PulumiNullFieldException("privateCloudName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/avs/kotlin/inputs/GetHcxEnterpriseSitePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.avs.kotlin.inputs

import com.pulumi.azurenative.avs.inputs.GetHcxEnterpriseSitePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property hcxEnterpriseSiteName Name of the HCX Enterprise Site in the private cloud
 * @property privateCloudName Name of the private cloud
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 */
public data class GetHcxEnterpriseSitePlainArgs(
    public val hcxEnterpriseSiteName: String,
    public val privateCloudName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.avs.inputs.GetHcxEnterpriseSitePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.avs.inputs.GetHcxEnterpriseSitePlainArgs =
        com.pulumi.azurenative.avs.inputs.GetHcxEnterpriseSitePlainArgs.builder()
            .hcxEnterpriseSiteName(hcxEnterpriseSiteName.let({ args0 -> args0 }))
            .privateCloudName(privateCloudName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetHcxEnterpriseSitePlainArgs].
 */
@PulumiTagMarker
public class GetHcxEnterpriseSitePlainArgsBuilder internal constructor() {
    private var hcxEnterpriseSiteName: String? = null

    private var privateCloudName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value Name of the HCX Enterprise Site in the private cloud
     */
    @JvmName("mphihocxhljxfvot")
    public suspend fun hcxEnterpriseSiteName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.hcxEnterpriseSiteName = mapped
    }

    /**
     * @param value Name of the private cloud
     */
    @JvmName("ubafhmbkpdafykgs")
    public suspend fun privateCloudName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.privateCloudName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("amujjbouuxgwbunb")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetHcxEnterpriseSitePlainArgs = GetHcxEnterpriseSitePlainArgs(
        hcxEnterpriseSiteName = hcxEnterpriseSiteName ?: throw
            PulumiNullFieldException("hcxEnterpriseSiteName"),
        privateCloudName = privateCloudName ?: throw PulumiNullFieldException("privateCloudName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}
